@@ -2,21 +2,23 @@ import os
 import argparse
 import configparser
 import asyncio
+from spydy import LOGO
 from .engine import Engine
 from .utils import check_configs
 from .defaults import *
 
 
-long_description = '''
-'''
+long_description = """
+"""
 
 
 def fire():
+    print(LOGO)
     arg_parser = argparse.ArgumentParser(
         prog="spydy",
         description="High level spider framework for web crawling based on pipleline",
         formatter_class=argparse.RawDescriptionHelpFormatter,
-        epilog=long_description
+        epilog=long_description,
     )
     arg_parser.add_argument(
         "configfile",
